@@ -6,7 +6,7 @@ use warnings;
 
 # Basic functionalities to include a simple Consumer
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 use Params::Util qw( _INSTANCE _STRING _NONNEGINT _POSINT _NUMBER );
@@ -29,7 +29,7 @@ use Kafka::Protocol qw(
     );
 use Kafka::Message;
 
-if ( !BITS64 ) { eval 'use Kafka::Int64; 1;' or die "Cannot load Kafka::Int64 : $@"; }
+if ( !BITS64 ) { eval 'use Kafka::Int64; 1;' or die "Cannot load Kafka::Int64 : $@"; }  ## no critic
 
 our $_last_error;
 our $_last_errorcode;
@@ -251,7 +251,7 @@ Kafka::Consumer - object interface to the consumer client
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Consumer> version 0.02
+This documentation refers to C<Kafka::Consumer> version 0.03
 
 =head1 SYNOPSIS
 
@@ -364,7 +364,7 @@ The Kafka consumer response has an ARRAY reference type for C<offsets>, and
 C<fetch> methods.
 For the C<offsets> response array has the offset integers, in descending order.
 
-For the C<fetch> response array has the class name
+For the C<fetch> response the array has the class name
 L<Kafka::Message|Kafka::Message> elements.
 
 =head2 CONSTRUCTOR
@@ -411,7 +411,7 @@ mode to true.
 =item *
 
 The arguments below B<offset>, B<max_size> or B<time>, B<max_number> are
-the additional information that might encode parameters of the messages
+the additional information that might be encoded parameters of the messages
 we want to access.
 
 =back
@@ -542,7 +542,7 @@ L</last_error>.
 
 =item C<Can't send>
 
-This means that the request can't be sent on a C<Kafka::IO> IO object socket.
+This means that the request can't be sent on a C<Kafka::IO> object socket.
 
 =item C<Can't recv>
 
